==> knative-model-6.8.0-sources.jar: io/fabric8/knative/eventing/v1/TriggerFilterFluent.java <==
package io.fabric8.knative.eventing.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerFilterFluent<A extends TriggerFilterFluent<A>> extends BaseFluent<A>{
  public TriggerFilterFluent() {
  }
  public TriggerFilterFluent(TriggerFilter instance) {
    instance = (instance != null ? instance : new TriggerFilter());

    if (instance != null) {
      this.withAttributes(instance.getAttributes());
      this.withAttributes(instance.getAttributes());
    }
  }
  private Map<String,String> attributes;
  public A addToAttributes(String key,String value) {
    if(this.attributes == null && key != null && value != null) { this.attributes = new LinkedHashMap(); }
    if(key != null && value != null) {this.attributes.put(key, value);} return (A)this;
  }
  public A addToAttributes(Map<String,String> map) {
    if(this.attributes == null && map != null) { this.attributes = new LinkedHashMap(); }
    if(map != null) { this.attributes.putAll(map);} return (A)this;
  }
  public A removeFromAttributes(String key) {
    if(this.attributes == null) { return (A) this; }
    if(key != null && this.attributes != null) {this.attributes.remove(key);} return (A)this;
  }
  public A removeFromAttributes(Map<String,String> map) {
    if(this.attributes == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.attributes != null){this.attributes.remove(key);}}} return (A)this;
  }
  public Map<String,String> getAttributes() {
    return this.attributes;
  }
  public <K,V>A withAttributes(Map<String,String> attributes) {
    if (attributes == null) { this.attributes =  null;} else {this.attributes = new LinkedHashMap(attributes);} return (A) this;
  }
  public boolean hasAttributes() {
    return this.attributes != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TriggerFilterFluent that = (TriggerFilterFluent) o;
    if (!java.util.Objects.equals(attributes, that.attributes)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(attributes,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (attributes != null && !attributes.isEmpty()) { sb.append("attributes:"); sb.append(attributes); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/eventing/v1/TriggerFilterFluent.java <==
package io.fabric8.knative.eventing.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class TriggerFilterFluent<A extends TriggerFilterFluent<A>> extends BaseFluent<A>{
  public TriggerFilterFluent() {
  }
  
  public TriggerFilterFluent(TriggerFilter instance) {
    this.copyInstance(instance);
  }
  private Map<String,String> attributes;
  
  protected void copyInstance(TriggerFilter instance) {
    instance = (instance != null ? instance : new TriggerFilter());
  
    if (instance != null) {
        this.withAttributes(instance.getAttributes());
        this.withAttributes(instance.getAttributes());
      }
  }
  
  public A addToAttributes(String key,String value) {
    if(this.attributes == null && key != null && value != null) { this.attributes = new LinkedHashMap(); }
    if(key != null && value != null) {this.attributes.put(key, value);} return (A)this;
  }
  
  public A addToAttributes(Map<String,String> map) {
    if(this.attributes == null && map != null) { this.attributes = new LinkedHashMap(); }
    if(map != null) { this.attributes.putAll(map);} return (A)this;
  }
  
  public A removeFromAttributes(String key) {
    if(this.attributes == null) { return (A) this; }
    if(key != null && this.attributes != null) {this.attributes.remove(key);} return (A)this;
  }
  
  public A removeFromAttributes(Map<String,String> map) {
    if(this.attributes == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.attributes != null){this.attributes.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getAttributes() {
    return this.attributes;
  }
  
  public <K,V>A withAttributes(Map<String,String> attributes) {
    if (attributes == null) { this.attributes =  null;} else {this.attributes = new LinkedHashMap(attributes);} return (A) this;
  }
  
  public boolean hasAttributes() {
    return this.attributes != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TriggerFilterFluent that = (TriggerFilterFluent) o;
    if (!java.util.Objects.equals(attributes, that.attributes)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(attributes,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (attributes != null && !attributes.isEmpty()) { sb.append("attributes:"); sb.append(attributes); }
    sb.append("}");
    return sb.toString();
  }
  

}
